@@ -17,24 +17,22 @@
 
 #include "editaliasdialog.h"
 #include <qobject.h>
-#include <kpushbutton.h>
+#include <QPushButton>
 #include <qwidget.h>
 #include <qstring.h>
-#include <klineedit.h>
 
-
-EditAliasDialog::EditAliasDialog( QWidget* parent )
-: QDialog( parent )
+EditAliasDialog::EditAliasDialog(QWidget *parent)
+    : QDialog(parent)
 {
-	setupUi( this );
-	
-	QObject::connect( alias, SIGNAL(textChanged(QString)), this, SLOT(checkButtonsEnabled()) );
-	QObject::connect( command, SIGNAL(textChanged(QString)), this, SLOT(checkButtonsEnabled()) );
-	QObject::connect( protocolList, SIGNAL(selectionChanged()), this, SLOT(checkButtonsEnabled()) );
-        QObject::connect( kPushButton3, SIGNAL(clicked()), this, SLOT(reject()) );
-        QObject::connect( addButton, SIGNAL(clicked()), this, SLOT(accept()) );
+    setupUi(this);
 
-	checkButtonsEnabled();
+    QObject::connect(alias, SIGNAL(textChanged(QString)), this, SLOT(checkButtonsEnabled()));
+    QObject::connect(command, SIGNAL(textChanged(QString)), this, SLOT(checkButtonsEnabled()));
+    QObject::connect(protocolList, SIGNAL(selectionChanged()), this, SLOT(checkButtonsEnabled()));
+    QObject::connect(kPushButton3, SIGNAL(clicked()), this, SLOT(reject()));
+    QObject::connect(addButton, SIGNAL(clicked()), this, SLOT(accept()));
+
+    checkButtonsEnabled();
 }
 
 EditAliasDialog::~EditAliasDialog()
@@ -43,12 +41,11 @@ EditAliasDialog::~EditAliasDialog()
 
 void EditAliasDialog::checkButtonsEnabled()
 {
-	if ( !alias->text().isEmpty() && !command->text().isEmpty() && !protocolList->selectedItems().isEmpty() )
-		addButton->setEnabled( true );
-	else
-		addButton->setEnabled( false ) ;
+    if (!alias->text().isEmpty() && !command->text().isEmpty() && !protocolList->selectedItems().isEmpty()) {
+        addButton->setEnabled(true);
+    } else {
+        addButton->setEnabled(false);
+    }
 }
 
-#include "editaliasdialog.moc"
-
 // kate: space-indent off; replace-tabs off; tab-width 4; indent-mode csands;
