@@ -1,13 +1,13 @@
 /*
     Kopete Groupwise Protocol
-    leaveconferencetask.cpp - Tell the server we are leaving a conference 
+    leaveconferencetask.cpp - Tell the server we are leaving a conference
+
+    Copyright (c) 2004      SUSE Linux AG	     http://www.suse.com
 
-    Copyright (c) 2004      SUSE Linux AG	 	 http://www.suse.com
-    
     Based on Iris, Copyright (C) 2003  Justin Karneges <justin@affinix.com>
 
     Kopete (c) 2002-2004 by the Kopete developers <kopete-devel@kde.org>
- 
+
     *************************************************************************
     *                                                                       *
     * This library is free software; you can redistribute it and/or         *
@@ -20,21 +20,18 @@
 
 #include "leaveconferencetask.h"
 
-LeaveConferenceTask::LeaveConferenceTask(Task* parent): RequestTask(parent)
+LeaveConferenceTask::LeaveConferenceTask(Task *parent) : RequestTask(parent)
 {
 }
 
-
 LeaveConferenceTask::~LeaveConferenceTask()
 {
 }
 
-void LeaveConferenceTask::leave( const GroupWise::ConferenceGuid & guid )
+void LeaveConferenceTask::leave(const GroupWise::ConferenceGuid &guid)
 {
-	Field::FieldList lst, tmp;
-	tmp.append( new Field::SingleField( Field::NM_A_SZ_OBJECT_ID, 0, NMFIELD_TYPE_UTF8, guid ) );
-	lst.append( new Field::MultiField( Field::NM_A_FA_CONVERSATION, NMFIELD_METHOD_VALID, 0, NMFIELD_TYPE_ARRAY, tmp ) );
-	createTransfer( "leaveconf", lst );
+    Field::FieldList lst, tmp;
+    tmp.append(new Field::SingleField(Field::NM_A_SZ_OBJECT_ID, 0, NMFIELD_TYPE_UTF8, guid));
+    lst.append(new Field::MultiField(Field::NM_A_FA_CONVERSATION, NMFIELD_METHOD_VALID, 0, NMFIELD_TYPE_ARRAY, tmp));
+    createTransfer(QStringLiteral("leaveconf"), lst);
 }
-
-#include "leaveconferencetask.moc"
