@@ -29,10 +29,10 @@ public:
 
 	void setForm(const Form &frm, const XData &_form);
 
-	bool take(const QDomElement &);
+	bool take(const QDomElement &) Q_DECL_OVERRIDE;
 	QDomElement iq() const;
 
-	void onGo();
+	void onGo() Q_DECL_OVERRIDE;
 
 private:
 	QDomElement _iq;
