@@ -20,8 +20,8 @@
 #include <kdebug.h>
 #include <kconfig.h>
 #include <kdialog.h>
-#include <klocale.h>
-#include <kmenu.h>
+#include <KLocalizedString>
+
 #include <kactionmenu.h>
 #include <kmessagebox.h>
 #include <ktoggleaction.h>
@@ -50,7 +50,6 @@
 #include "oscarsettings.h"
 #include "oscarstatusmanager.h"
 
-
 const Oscar::DWORD AIM_ONLINE = 0x0;
 const Oscar::DWORD AIM_AWAY = 0x1;
 
@@ -97,7 +96,7 @@ Kopete::ChatSession* AIMMyselfContact::manager( Kopete::Contact::CanCreateFlags
 	kDebug(OSCAR_AIM_DEBUG) ;
 	Kopete::ContactPtrList chatMembers;
 	chatMembers.append( this );
-	Kopete::ChatSession* genericManager = 0L;
+	Kopete::ChatSession* genericManager = nullptr;
 	genericManager = Kopete::ChatSessionManager::self()->findChatSession( account()->myself(), chatMembers, protocol() );
 	AIMChatSession* session = dynamic_cast<AIMChatSession*>( genericManager );
 
@@ -106,8 +105,7 @@ Kopete::ChatSession* AIMMyselfContact::manager( Kopete::Contact::CanCreateFlags
 		session = new AIMChatSession( this, chatMembers, account()->protocol(), exchange, room );
 		session->setEngine( m_acct->engine() );
 
-		connect( session, SIGNAL(messageSent(Kopete::Message&,Kopete::ChatSession*)),
-				this, SLOT(sendMessage(Kopete::Message&,Kopete::ChatSession*)) );
+		connect(session, &AIMChatSession::messageSent, this, &AIMMyselfContact::sendMessage);
 		m_chatRoomSessions.append( session );
 	}
 	return session;
@@ -213,7 +211,6 @@ void AIMMyselfContact::sendMessage( Kopete::Message& message, Kopete::ChatSessio
 	session->messageSucceeded();
 }
 
-
 AIMAccount::AIMAccount(Kopete::Protocol *parent, QString accountID)
 	: OscarAccount(parent, accountID, false)
 {
@@ -238,14 +235,14 @@ AIMAccount::AIMAccount(Kopete::Protocol *parent, QString accountID)
 			this, SLOT(userLeftChat(Oscar::WORD,QString,QString)) );
 
 	// Create actions
-	mJoinChatAction = new KAction( i18n( "Join Chat..." ), this );
-	QObject::connect( mJoinChatAction, SIGNAL(triggered(bool)), this, SLOT(slotJoinChat()) );
-	
-	mEditInfoAction = new KAction( KIcon("user-properties"), i18n( "Edit User Info..." ), this );
-	QObject::connect( mEditInfoAction, SIGNAL(triggered(bool)), this, SLOT(slotEditInfo()) );
-	
+	mJoinChatAction = new QAction( i18n( "Join Chat..." ), this );
+	QObject::connect(mJoinChatAction, &QAction::triggered, this, &AIMAccount::slotJoinChat);
+
+    mEditInfoAction = new QAction( QIcon::fromTheme("user-properties"), i18n( "Edit User Info..." ), this );
+	QObject::connect(mEditInfoAction, &QAction::triggered, this, &AIMAccount::slotEditInfo);
+
 	mActionInvisible = new KToggleAction( i18n( "In&visible" ), this );
-	QObject::connect( mActionInvisible, SIGNAL(triggered(bool)), this, SLOT(slotToggleInvisible()) );
+	QObject::connect(mActionInvisible, &KToggleAction::triggered, this, &AIMAccount::slotToggleInvisible);
 }
 
 AIMAccount::~AIMAccount()
@@ -296,7 +293,7 @@ void AIMAccount::fillActionMenu( KActionMenu *actionMenu )
 	actionMenu->addAction( mEditInfoAction );
 
 	Oscar::Presence pres( presence().type(), presence().flags() | Oscar::Presence::Invisible );
-	mActionInvisible->setIcon( KIcon( protocol()->statusManager()->onlineStatusOf( pres ).iconFor( this ) ) );
+    mActionInvisible->setIcon( QIcon( protocol()->statusManager()->onlineStatusOf( pres ).iconFor( this ) ) );
 	mActionInvisible->setChecked( (presence().flags() & Oscar::Presence::Invisible) == Oscar::Presence::Invisible );
 	actionMenu->addAction( mActionInvisible );
 }
@@ -422,8 +419,7 @@ void AIMAccount::slotJoinChat()
 	if ( !m_joinChatDialog )
 	{
 		m_joinChatDialog = new AIMJoinChatUI( this, Kopete::UI::Global::mainWidget() );
-		QObject::connect( m_joinChatDialog, SIGNAL(closing(int)),
-				this, SLOT(joinChatDialogClosed(int)) );
+		QObject::connect(m_joinChatDialog, &AIMJoinChatUI::closing, this, &AIMAccount::joinChatDialogClosed);
 		QList<int> list = engine()->chatExchangeList();
 		m_joinChatDialog->setExchangeList( list );
 		m_joinChatDialog->show();
@@ -443,7 +439,7 @@ void AIMAccount::joinChatDialogClosed( int code )
 	}
 
 	m_joinChatDialog->delayedDestruct();
-	m_joinChatDialog = 0L;
+	m_joinChatDialog = nullptr;
 }
 
 void AIMAccount::loginActions()
@@ -506,7 +502,7 @@ void AIMAccount::messageReceived( const Oscar::Message& message )
 			Kopete::Message chatMessage( myself(), aimSender );
 			chatMessage.setHtmlBody( msg );
 			chatMessage.setDirection( Kopete::Message::Outbound );
-			
+
 			kDebug(14152) << "Sending autoresponse";
 			// Send the message
 			aimSender->sendAutoResponse( chatMessage );
@@ -631,7 +627,6 @@ void AIMAccount::userLeftChat( Oscar::WORD exchange, const QString& room, const
 	}
 }
 
-
 void AIMAccount::connectWithPassword( const QString &password )
 {
 	if ( password.isNull() )
@@ -709,5 +704,3 @@ void AIMAccount::setPrivacySettings( int privacy )
 	engine()->setPrivacyTLVs( privacyByte, userClasses );
 }
 
-#include "aimaccount.moc"
-//kate: tab-width 4; indent-mode csands;
