@@ -17,7 +17,7 @@
 
 #include "aimprotocol.h"
 
-#include <kgenericfactory.h>
+#include <kpluginfactory.h>
 
 #include "aimaccount.h"
 #include "aimstatusmanager.h"
@@ -36,15 +36,14 @@
 K_PLUGIN_FACTORY( AIMProtocolFactory, registerPlugin<AIMProtocol>(); )
 K_EXPORT_PLUGIN( AIMProtocolFactory( "kopete_aim" ) )
 
-AIMProtocol* AIMProtocol::protocolStatic_ = 0L;
-
+AIMProtocol* AIMProtocol::protocolStatic_ = nullptr;
 
 AIMProtocolHandler::AIMProtocolHandler() : Kopete::MimeTypeHandler(false)
 {
 	registerAsProtocolHandler(QString::fromLatin1("aim"));
 }
 
-void AIMProtocolHandler::handleURL(const QString&, const KUrl &url) const
+void AIMProtocolHandler::handleURL(const QString&, const QUrl &url) const
 {
 /**
  * Send a Message  =================================================
@@ -220,11 +219,8 @@ void AIMProtocolHandler::handleURL(const QString&, const KUrl &url) const
 
 }
 
-
-
-
 AIMProtocol::AIMProtocol(QObject *parent, const QVariantList &)
-: OscarProtocol( AIMProtocolFactory::componentData(), parent, true ),
+: OscarProtocol( parent, true ),
 	clientProfile( "clientProfile", i18n( "User Profile"), 0, Kopete::PropertyTmpl::RichTextProperty)
 {
 	if (protocolStatic_)
@@ -273,4 +269,3 @@ OscarStatusManager *AIMProtocol::statusManager() const
 }
 
 #include "aimprotocol.moc"
-// vim: set noet ts=4 sts=4 sw=4:
