@@ -21,23 +21,23 @@
 #include <qapplication.h>
 #include <qtextcodec.h>
 #include <qtimer.h>
-#include <QtXml/QDomDocument>
-#include <QtXml/QDomNodeList>
-#include <QtGui/QTextDocument>
-#include <QtGui/QTextCharFormat>
-#include <QtGui/QTextBlock>
+#include <QCryptographicHash>
+#include <QDomDocument>
+#include <QDomNodeList>
+#include <QTextDocument>
+#include <QTextCharFormat>
+#include <QTextBlock>
 
-#include <kaction.h>
+#include <QAction>
 #include <kdebug.h>
-#include <klocale.h>
+#include <KLocalizedString>
 #include <krandom.h>
 #include <kcodecs.h>
 #include <kmessagebox.h>
-#include <kstandarddirs.h>
-#include <kinputdialog.h>
 
-#include <kdeversion.h>
-#include <kfiledialog.h>
+#include <qinputdialog.h>
+
+#include <qfiledialog.h>
 
 #include "kopeteaccount.h"
 #include "kopetechatsessionmanager.h"
@@ -66,7 +66,7 @@ OscarContact::OscarContact( Kopete::Account* account, const QString& name,
 {
 	mAccount = static_cast<OscarAccount*>(account);
 	mName = name;
-	mMsgManager = 0L;
+	mMsgManager = nullptr;
 	m_buddyIconDirty = false;
 	m_oesd = 0;
 
@@ -153,28 +153,28 @@ void OscarContact::deleteContact()
 
 void OscarContact::chatSessionDestroyed()
 {
-	mMsgManager = 0L;
+	mMsgManager = nullptr;
 }
 
 // Called when the metacontact owning this contact has changed groups
 void OscarContact::sync(unsigned int flags)
 {
-	/* 
+	/*
 	 * If the contact has changed groups, then we update the server
 	 *   adding the group if it doesn't exist, changing the ssi item
 	 *   contained in the client and updating the contact's ssi item
 	 * Otherwise, we don't do much
 	 */
-	
+
 	if( !metaContact() || metaContact()->isTemporary() )
 		return;
-	
+
 	if ( (flags & Kopete::Contact::MovedBetweenGroup) == Kopete::Contact::MovedBetweenGroup )
 	{
-		
+
 		kDebug(OSCAR_GEN_DEBUG) << "Moving a contact between groups";
 		ContactManager* ssiManager = mAccount->engine()->ssiManager();
-		
+
 		OContact oldGroup = ssiManager->findGroup( m_ssiItem.gid() );
 		Kopete::Group* newGroup = metaContact()->groups().first();
 		QString newGroupName = newGroup->displayName();
@@ -182,7 +182,7 @@ void OscarContact::sync(unsigned int flags)
 			newGroupName = "Buddies";
 		if ( newGroupName == oldGroup.name() )
 			return; //we didn't really move
-		
+
 		if ( m_ssiItem.isValid() )
 			mAccount->changeContactGroupInSSI( contactId(), newGroupName, true );
 		else
@@ -199,7 +199,7 @@ void OscarContact::sync(unsigned int flags)
 void OscarContact::userInfoUpdated( const QString& contact, const UserDetails& details  )
 {
 	Q_UNUSED( contact );
-	
+
 	if ( details.buddyIconHash().size() > 0 && details.buddyIconHash() != m_details.buddyIconHash() )
 	{
 		OscarProtocol *p = static_cast<OscarProtocol*>(protocol());
@@ -207,7 +207,7 @@ void OscarContact::userInfoUpdated( const QString& contact, const UserDetails& d
 		if ( property( p->buddyIconHash ).value().toByteArray() != details.buddyIconHash() || QFileInfo(photoPath).size() == 0 )
 		{
 			m_buddyIconDirty = true;
-			
+
 			if ( !mAccount->engine()->hasIconConnection() )
 			{
 				mAccount->engine()->connectToIconServer();
@@ -221,7 +221,7 @@ void OscarContact::userInfoUpdated( const QString& contact, const UserDetails& d
 			}
 		}
 	}
-	
+
 	setProperty( Kopete::Global::Properties::self()->onlineSince(), details.onlineSinceTime() );
 	setIdleTime( details.idleTime() );
 	m_warningLevel = details.warningLevel();
@@ -241,7 +241,7 @@ void OscarContact::userInfoUpdated( const QString& contact, const UserDetails& d
 	//		                "%1", m_details.clientName() );
 	//	}
 	//}
-	
+
 	// and now for some general informative capabilities
 	if ( m_details.hasCap( CAP_BUDDYICON ) )
 		capList << i18n( "Buddy icons" );
@@ -294,7 +294,7 @@ void OscarContact::messageAck( const QString& contact, uint messageId )
 {
 	if ( Oscar::normalize( contact ) != Oscar::normalize( contactId() ) )
 		return;
-	
+
 	Kopete::ChatSession* chatSession = manager();
 	if ( chatSession )
 		chatSession->receivedMessageState( messageId, Kopete::Message::StateSent );
@@ -304,7 +304,7 @@ void OscarContact::messageError( const QString& contact, uint messageId )
 {
 	if ( Oscar::normalize( contact ) != Oscar::normalize( contactId() ) )
 		return;
-	
+
 	Kopete::ChatSession* chatSession = manager();
 	if ( chatSession )
 		chatSession->receivedMessageState( messageId, Kopete::Message::StateError );
@@ -352,18 +352,19 @@ void OscarContact::setEncoding( int mib )
 }
 
 //here's where a filetransfer usually begins
-//could be called by a KAction or our dcop code or something
-void OscarContact::sendFile( const KUrl &sourceURL, const QString &altFileName, uint fileSize )
+//could be called by a QAction or our dcop code or something
+void OscarContact::sendFile( const QUrl &sourceURL, const QString &altFileName, uint fileSize )
 {
-	kDebug(OSCAR_GEN_DEBUG) << "file: '" << sourceURL 
+	kDebug(OSCAR_GEN_DEBUG) << "file: '" << sourceURL
 		<< "' '" << altFileName << "' size " << fileSize << endl;
 	QStringList files;
 
 	//If the file location is null, then get it from a file open dialog
-	if( !sourceURL.isValid() )
-		files = KFileDialog::getOpenFileNames( KUrl() ,"*", 0l  , i18n( "Kopete File Transfer" ));
-	else
-		files << sourceURL.path(KUrl::RemoveTrailingSlash);
+    if( !sourceURL.isValid() ) {
+        files = QFileDialog::getOpenFileNames( nullptr, i18n( "Kopete File Transfer" ), QString() , "*");
+    } else {
+        //FIXME KF5 files << sourceURL.path(KUrl::RemoveTrailingSlash);
+    }
 
 	if( files.isEmpty() )
 	{
@@ -393,7 +394,7 @@ void OscarContact::setAwayMessage( const QString &message )
 {
 	kDebug(OSCAR_AIM_DEBUG) <<
 		"Called for '" << contactId() << "', away msg='" << message << "'" << endl;
-	
+
 	if ( !message.isEmpty() )
 		setProperty( static_cast<OscarProtocol*>( protocol() )->statusMessage, filterAwayMessage( message ) );
 	else
@@ -419,7 +420,7 @@ void OscarContact::requestAuthorization()
 	                    "Do you want to send an authorization request?\n\nReason for requesting authorization:",
 	                    displayName() );
 
-	QString reason = KInputDialog::getText( i18n("Request Authorization"), info,
+    QString reason = QInputDialog::getText( nullptr, i18n("Request Authorization"), info, QLineEdit::Normal,
 	                                        i18n("Please authorize me so I can add you to my contact list") );
 	if ( !reason.isNull() )
 		mAccount->engine()->requestAuth( contactId(), reason );
@@ -498,7 +499,7 @@ void OscarContact::slotSendMsg(Kopete::Message& message, Kopete::ChatSession *)
 
 				QString text = currentFragment.text();
 				lastFragmentHasLineSeparator = text.endsWith( QChar::LineSeparator );
-				rtfText += Qt::escape( text );
+				rtfText += text.toHtmlEscaped();
 				defaultCharFormat = format;
 			}
 		}
@@ -548,11 +549,11 @@ void OscarContact::changeEncodingDialogClosed( int result )
 {
 	if ( result == QDialog::Accepted )
 		setEncoding( m_oesd->selectedEncoding() );
-	
+
 	if ( m_oesd )
 	{
 		m_oesd->deleteLater();
-		m_oesd = 0L;
+		m_oesd = nullptr;
 	}
 }
 
@@ -569,11 +570,11 @@ void OscarContact::haveIcon( const QString& user, QByteArray icon )
 {
 	if ( Oscar::normalize( user ) != Oscar::normalize( contactId() ) )
 		return;
-	
+
 	kDebug(OSCAR_GEN_DEBUG) << "Updating icon for " << contactId();
-	
-	KMD5 buddyIconHash( icon );
-	if ( memcmp( buddyIconHash.rawDigest(), m_details.buddyIconHash().data(), 16 ) == 0 )
+
+	QByteArray buddyIconHash = QCryptographicHash::hash( icon, QCryptographicHash::Md5 );
+	if ( memcmp( buddyIconHash, m_details.buddyIconHash().data(), 16 ) == 0 )
 	{
 		QImage img;
 		img.loadFromData(icon);
@@ -605,7 +606,7 @@ void OscarContact::receivedStatusMessage( const QString& contact, const QString&
 {
 	if ( Oscar::normalize( contact ) != Oscar::normalize( contactId() ) )
 		return;
-	
+
 	setAwayMessage( message );
 }
 
@@ -649,16 +650,14 @@ QString OscarContact::brMargin( int margin, int fontPointSize, bool forceBr ) co
 {
 	int brHeight = ( fontPointSize == 0 ) ? 12 : fontPointSize;
 	int brCount = margin / brHeight;
-	
+
 	if ( brCount <= 0 )
 		return ( forceBr ) ? "<BR>" : "";
-	
+
 	QString s;
 	while ( brCount-- > 0 )
 		s += "<BR>";
-	
+
 	return s;
 }
 
-#include "oscarcontact.moc"
-//kate: tab-width 4; indent-mode csands;
